function dddmmssss = deg2dddmmssss(deg, precision)
    % DEG2DDMMSS pretvori kot, ki je podan v decimalnih stopinjah v obliko zapisa ddd.mmssss.
    %   
    %   dddmmssss = deg2dddmmssss(deg, precision)
    %
    %   VHODNI PARAMETRI:
    %     deg       ... kot v decimalnih stopinjah
    %     precision ... število decimalk za zaokroževanje sekund (za robni primer, da niso sekunde 60)
    %
    %   IZHODNI PARAMETRI:
    %     dddmmssss ... kot v formatu ddd.mmssss
    %
    %   AVTOR: Klemen Ritlop
    %   2024-02-20
    
    arguments
        deg       (1,1) {mustBeNumeric, mustBeReal}
        precision (1,1) {mustBeNumeric, mustBeInteger} = 10
    end

    sgn = sign(deg);
    
    deg = abs(deg);
    degrees = fix(deg);
    minutes_decimal = (deg - degrees) * 60;
    minutes = fix(minutes_decimal);
    seconds = (minutes_decimal - minutes) * 60;
    
    % robni primer 1, ko so sekunde zelo blizu 60
    % Npr. pri zaokroževanju ddd.mmssss zapisa na 7 decimalk zapisa (tj. 3 decimalke sekunde)
    % se zgodi sledeče: 15.15594999... -> 15.1560000, sekunde pa lahko zavzamejo vrednosti med 00 in 59.
    if abs(seconds - 60) < 10^(-precision)
        minutes = minutes + 1;
        seconds = 0;
    end
    
    % robni primer 2, ki se lahko zgodi zaradi robnega primera 1
    % Če je vrednost minut 59 -> 59 + 1 = 60, minute pa lahko zavzamejo vrednosti med 00 in 59.
    if abs(minutes - 60) < 1e-12
        degrees = degrees + 1;
        minutes = 0;
    end
    
    dddmmssss = sgn * (degrees + minutes/100 + seconds/10000);

end