function P_XYZ = sferne2xyz(P_llh, R)
    % SFERNE2XYZ pretvori sferne koordinate v 3D kartezične koordinate.
    %   
    %   P_XYZ = sferne2xyz( [lat, lon, h], R = **6371000** )
    %
    %   VHODNI PARAMETRI:
    %     P_llh ... [lat, lon, h], lat in lon v decimalnih stopinjah
    %     R     ... polmer krogle [m] (privzeto: 6371000 m)
    %
    %   IZHODNI PARAMETRI:
    %     P_XYZ ... 3D kartezične koordinate [X, Y, Z]
    %
    %   AVTOR: Klemen Ritlop
    %   2021-03-02

    arguments
        P_llh (1,3) {mustBeNumeric,mustBeReal}
        R double {mustBeNumeric,mustBeReal, mustBePositive} = 6371000.0
    end
       
    lat = P_llh(1);
    lon = P_llh(2);
    h = P_llh(3);
    
    lat = deg2rad(lat);
    lon = deg2rad(lon);
    
    r = R + h;
    X = r * cos(lat) * cos(lon);
    Y = r * cos(lat) * sin(lon);
    Z = r * sin(lat);
    
    P_XYZ = [X, Y, Z];
    
end
