function P_llh = xyz2sferne(P_XYZ, R)
    % XYZ2SFERNE pretvori 3D kartezične koordinate v sferne koordinate.
    %   
    %   P_llh = xyz2sferne( [X, Y, Z], R = **6371000** )
    %
    %   VHODNI PARAMETRI:
    %     P_XYZ ... 3D kartezične koordinate [X, Y, Z]
    %     R     ... polmer krogle [m] (privzeto: 6371000 m)
    %
    %   IZHODNI PARAMETRI:
    %     P_llh ... [lat, lon, h], lat in lon v decimalnih stopinjah
    %
    %   AVTOR: Klemen Ritlop
    %   2021-03-02
    %
    %   SPREMEMBE:
    %   2025-02-17: Sprememba pri izračunu lon - uporaba funkcije atan2
    %               namesto if-pogojev.    
   
    arguments
        P_XYZ (1,3) {mustBeNumeric,mustBeReal}
        R double {mustBeNumeric,mustBeReal, mustBePositive} = 6371000.0
    end
    
    X = P_XYZ(1);
    Y = P_XYZ(2);
    Z = P_XYZ(3);
    
    r = sqrt(X^2 + Y^2 + Z^2);

    lat = asin(Z / r);
    lon = atan2(Y, X);
    
    lat = rad2deg(lat);
    lon = rad2deg(lon);
    
    h = r - R;
    
    P_llh = [lat, lon, h];

end

